/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.ejb;

import java.util.Map;
import java.util.Set;

import message.MessageBoxKey;

/**
 * This is the remote interface that the client calls to have the EJB do the
 * work.
 * 
 * @author Michelle Osmond
 * @version 1.1
 */
public interface PortalMessageStore extends javax.ejb.EJBObject
{
    void saveInputMapping(MessageBoxKey key, MessageBoxKey source) throws java.rmi.RemoteException;

    void deleteInput(MessageBoxKey key) throws java.rmi.RemoteException;

    void saveOutputMapping(MessageBoxKey key, MessageBoxKey target) throws java.rmi.RemoteException;

    void clearAllOutputMappings(MessageBoxKey key) throws java.rmi.RemoteException;

    void deleteOutput(MessageBoxKey key) throws java.rmi.RemoteException;

    Set findOutputTargets(MessageBoxKey key) throws java.rmi.RemoteException;

    MessageBoxKey getInputSource(MessageBoxKey key) throws java.rmi.RemoteException;

    Object getMessage(MessageBoxKey key) throws java.rmi.RemoteException;

    void sendMessage(Set targetKeys, Object message) throws java.rmi.RemoteException;

    Set getInputKeys(String portletID) throws java.rmi.RemoteException;

    Set getOutputKeys(String portletID) throws java.rmi.RemoteException;

    Map getBoxes() throws java.rmi.RemoteException;

    Set getPublicBoxKeys() throws java.rmi.RemoteException;

    Set getAllInputKeys() throws java.rmi.RemoteException;

    Set getAllOutputKeys() throws java.rmi.RemoteException;
}
