/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.ejb;

import java.util.Map;
import java.util.Set;

import javax.ejb.EntityContext;

import message.MessageBoxKey;
import message.MessageStore;
import message.store.BasicMessageStore;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * The PortalMessageStoreBean contains a MessageStore for the session.
 * 
 * @author Michelle Osmond
 * @version 1.1
 */

public abstract class PortalMessageStoreBean implements javax.ejb.EntityBean
{
    private static final Log log = LogFactory.getLog(PortalMessageStoreBean.class);

    public void setEntityContext(EntityContext cntx)
    {
    }

    public void unsetEntityContext()
    {
    }

    public void ejbLoad()
    {
    }

    public void ejbStore()
    {
    }

    public void ejbActivate()
    {
    }

    public void ejbPassivate()
    {
    }

    public void ejbRemove()
    {
    }

    public String ejbCreate(String sessionID) throws javax.ejb.CreateException
    {
        if (log.isDebugEnabled())
        {
            log.debug("ejbCreate(" + sessionID + ")");
        }
        setSessionID(sessionID);
        MessageStore store = new BasicMessageStore();
        store.initialise(sessionID);
        setStore(store);
        log.debug("have created and stored new message store: " + store + " for session id " + getSessionID());
        log.debug("- getStore: " + getStore());
        return sessionID;
    }

    public void ejbPostCreate(String sessionID)
    {
    }

    // ------------- Accessor methods ---------------------

    public abstract void setSessionID(String sessionID);

    public abstract String getSessionID();

    public abstract void setStore(MessageStore store);

    public abstract MessageStore getStore();

    // ------------- PortalMessageStore methods (delegate to MessageStore)
    // --------------

    public void saveInputMapping(MessageBoxKey key, MessageBoxKey source) throws java.rmi.RemoteException
    {
        log.debug("saveInputMapping: " + key + " <= " + source);
        MessageStore store = getStore();
        store.saveInputMapping(key, source);
        setStore(store);
    }

    public void deleteInput(MessageBoxKey key) throws java.rmi.RemoteException
    {
        log.debug("deleteInput: " + key);
        MessageStore store = getStore();
        store.deleteInput(key);
        setStore(store);
    }

    public void saveOutputMapping(MessageBoxKey key, MessageBoxKey target) throws java.rmi.RemoteException
    {
        log.debug("saveOutputMapping: " + key + " => " + target);
        MessageStore store = getStore();
        store.saveOutputMapping(key, target);
        setStore(store);
    }

    public void clearAllOutputMappings(MessageBoxKey key) throws java.rmi.RemoteException
    {
        log.debug("clearAllOutputMappings for: " + key);
        MessageStore store = getStore();
        store.clearAllOutputMappings(key);
        setStore(store);
    }

    public void deleteOutput(MessageBoxKey key) throws java.rmi.RemoteException
    {
        log.debug("deleteOutput for: " + key);
        MessageStore store = getStore();
        store.deleteOutput(key);
        setStore(store);
    }

    public Set findOutputTargets(MessageBoxKey key) throws java.rmi.RemoteException
    {
        log.debug("findOutputTargets for: " + key);
        return getStore().findOutputTargets(key);
    }

    public MessageBoxKey getInputSource(MessageBoxKey key) throws java.rmi.RemoteException
    {
        log.debug("getInputSource for: " + key);
        return getStore().getInputSource(key);
    }

    public Object getMessage(MessageBoxKey key) throws java.rmi.RemoteException
    {
        log.debug("getMessage: " + key + "=" + getStore().getMessage(key));
        return getStore().getMessage(key);
    }

    public void sendMessage(Set targetKeys, Object message) throws java.rmi.RemoteException
    {
        log.debug("sendMessage: " + message + " to " + targetKeys);
        MessageStore store = getStore();
        store.sendMessage(targetKeys, message);
        setStore(store);
    }

    public Set getInputKeys(String portletID) throws java.rmi.RemoteException
    {
        log.debug("getInputKeys for: " + portletID);
        return getStore().getInputKeys(portletID);
    }

    public Set getOutputKeys(String portletID) throws java.rmi.RemoteException
    {
        log.debug("getOutputKeys for: " + portletID);
        return getStore().getOutputKeys(portletID);
    }

    public Map getBoxes() throws java.rmi.RemoteException
    {
        log.debug("getBoxes");
        return getStore().getBoxes();
    }

    public Set getPublicBoxKeys() throws java.rmi.RemoteException
    {
        log.debug("getPublicBoxKeys");
        return getStore().getPublicBoxKeys();
    }

    public Set getAllInputKeys() throws java.rmi.RemoteException
    {
        log.debug("getAllInputKeys");
        return getStore().getAllInputKeys();
    }

    public Set getAllOutputKeys() throws java.rmi.RemoteException
    {
        log.debug("getAllOutputKeys");
        return getStore().getAllOutputKeys();
    }

}
