/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Iterator;
import java.util.SortedSet;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletRequest;
import javax.portlet.PortletSession;
import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import message.MessageHelper;

/**
 * A portlet that sends and receives messages.
 * 
 * @author Michelle Osmond
 * @version 1.1
 * @see ListingPortlet
 * @see AmazonSearchBookPortlet
 */
public class AuthorDetailsPortlet extends GenericPortlet
{
    public void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        PortletSession portletSession = request.getPortletSession(true);
        String id = getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);

        // load this portlet's inputs and outputs from preferences
        MessageHelper.loadPrefs(request, id, msgSessionId);

        response.setContentType("text/html");
        PrintWriter writer = response.getWriter();

        writer.write("<p><i>portlet instance id: " + id + "</i></p>");

        MessageHelper helper = new MessageHelper(portletSession, id, msgSessionId);
        String broadcastAuthor = helper.getAsString("author");
        // print out the author details
        if (broadcastAuthor == null || broadcastAuthor.length() <= 0)
        {
            writer.write("No author selected.");
            return;
        }

        writer.write("<p>Selected author: <b>" + broadcastAuthor + "</b></p>");

        String website = Library.getWebsite(broadcastAuthor);
        writer.write("<p><a href='" + website + "'>" + website + "</a></p>");

        // draw the book list
        writer.write("<p><b>Books:</b></p>");

        writer.write("<table border='0'>");
        writer.write("<tr><th>Title</th></tr>");
        SortedSet books = Library.getBooks(broadcastAuthor);

        PortletURL bookUrl = response.createActionURL();
        bookUrl.setParameter("myAuthor", broadcastAuthor);

        for (Iterator it = books.iterator(); it.hasNext();)
        {
            String book = it.next().toString();
            bookUrl.setParameter("myBook", book);
            writer.write("<tr>");
            writer.write("<td><a href='" + bookUrl.toString() + "'>" + book + "</a></td>");
            writer.write("</tr>");
        }
        writer.write("</table>");
    }

    public void doEdit(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        doView(request, response);
    }

    public void doHelp(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
    }

    public void processAction(ActionRequest request, ActionResponse actionResponse) throws PortletException,
            java.io.IOException
    {

        PortletSession portletSession = request.getPortletSession(true);

        String id = getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);
        MessageHelper helper = new MessageHelper(portletSession, id, msgSessionId);

        String myAuthor = request.getParameter("myAuthor");
        if (myAuthor != null && myAuthor.length() > 0)
        {
            helper.send("author", myAuthor);
        }

        String myBook = request.getParameter("myBook");
        if (myBook != null && myBook.length() > 0)
        {
            helper.send("book", myBook);
        }
    }

    public String getInstanceID(PortletRequest request)
    {
        return "AuthorDetails" + MessageHelper.getPortletID(request);
    }
}
