/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Iterator;
import java.util.Set;
import java.util.SortedMap;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletException;
import javax.portlet.PortletRequest;
import javax.portlet.PortletSession;
import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import message.MessageHelper;

/**
 * A portlet that sends and receives messages.
 * 
 * @author Michelle Osmond
 * @version 1.1
 * @see WiredListingPortlet
 * @see AuthorDetailsPortlet
 * @see AmazonSearchBookPortlet
 */
public class ListingPortlet extends JSPPortlet
{

    public void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {

        PortletSession portletSession = request.getPortletSession(true);
        String id = getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);

        // load this portlet's inputs and outputs from preferences
        MessageHelper.loadPrefs(request, id, msgSessionId);

        response.setContentType("text/html");
        PrintWriter writer = response.getWriter();

        writer.write("<p><i>portlet instance id: " + id + "</i></p>");

        // See if there has been any messages broadcast that we need to pick up
        MessageHelper helper = new MessageHelper(portletSession, id, msgSessionId);
        String broadcastAuthor = helper.getAsString("author");
        String broadcastBook = helper.getAsString("book");
        // all we do with the messages is print them out
        if (broadcastAuthor != null && broadcastAuthor.length() > 0)
        {
            writer.write("<p>Selected author: <b>" + broadcastAuthor + "</b></p>");
        }
        if (broadcastBook != null && broadcastBook.length() > 0)
        {
            writer.write("<p>Selected book: <b>" + broadcastBook + "</b></p>");
        }

        // draw the listing table
        writer.write("<p><b>All books:</b></p>");

        writer.write("<table border='1'>");
        writer.write("<tr><th>Author</th><th>Title</th></tr>");
        SortedMap listing = Library.getListing();
        for (Iterator it = listing.keySet().iterator(); it.hasNext();)
        {
            String author = it.next().toString();

            PortletURL authorUrl = response.createActionURL();
            authorUrl.setParameter("myAuthor", author);
            authorUrl.setParameter("myBook", "");
            PortletURL bookUrl = response.createActionURL();
            bookUrl.setParameter("myAuthor", author);

            Set books = (Set) listing.get(author);

            for (Iterator it2 = books.iterator(); it2.hasNext();)
            {
                String book = it2.next().toString();
                bookUrl.setParameter("myBook", book);
                writer.write("<tr>");
                writer.write("<td><a href='" + authorUrl.toString() + "'>" + author + "</a></td>");
                writer.write("<td><a href='" + bookUrl.toString() + "'>" + book + "</a></td>");
                writer.write("</tr>");
            }
        }
        writer.write("</table>");
    }

    public void doEdit(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        doView(request, response);
    }

    public void doHelp(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
    }

    public void processAction(ActionRequest request, ActionResponse actionResponse) throws PortletException,
            java.io.IOException
    {
        PortletSession portletSession = request.getPortletSession(true);

        String id = getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);
        MessageHelper helper = new MessageHelper(portletSession, id, msgSessionId);

        String myAuthor = request.getParameter("myAuthor");
        if (myAuthor != null)
        {
            helper.send("author", myAuthor);
        }

        String myBook = request.getParameter("myBook");
        if (myBook != null)
        {
            helper.send("book", myBook);
        }
    }

    public String getInstanceID(PortletRequest request)
    {
        return "Listing" + MessageHelper.getPortletID(request);
    }
}
