/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.portlets;

import java.io.IOException;
import java.io.PrintWriter;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletMode;
import javax.portlet.PortletRequest;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import message.MessageHelper;
import message.MessageUtils;

/**
 * Example portlet for demonstrating the use of the messaging library.
 * 
 * @see message.portlets.Portlet1
 * 
 * @author Michelle Osmond
 * @version 1.1
 */
public class Portlet2 extends GenericPortlet
{
    protected void doView(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        String id = this.getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);
        MessageHelper.loadPrefs(request, id, msgSessionId);

        response.setContentType("text/html");
        PrintWriter out = response.getWriter();

        out.println("<h4>Portlet2</h4>");

        out.println("<b>Message Session ID:</b> " + msgSessionId + "<br/>");
        out.println("<b>Portlet ID:</b> " + id + "<br/>");
        out.println("<b>Portlet App:</b> " + request.getContextPath() + "<br/>");

        out
            .println("<p>This portlet will read in a message, referring to it as \"<code>c_val</code>\" in its code.<br />");
        out
            .println("The portlet's default preferences in <code>portlet.xml</code> have been set up so that "
                    + "this local \"<code>c_val</code>\" message will read from a public message box named \"<code>b_val</code>\""
                    + " (<a href=\"" + request.getContextPath()
                    + "/portlet2_prefs.html\" target=\"_blank\">show me</a>)</p>");

        out
            .println("<p>Therefore, with the default settings on both portlets, "
                    + "Portlet1's <code>a_val</code> =&gt; public <code>b_val</code> =&gt; Portlet2's <code>c_val</code>.</p>");

        out.println("<h4>Read in the Message</h4>");

        out
            .println("<p>See what happens when we try to read in \"a_val\", \"b_val\" and \"c_val\" using <code>MessageHelper .get(\"a_val\")</code> etc. "
                    + "The message should show up below in <b>c_val</b>.</p>");

        MessageHelper msgh = new MessageHelper(request.getPortletSession(true), id, msgSessionId);
        String a_val = (String) msgh.get("a_val");
        String b_val = (String) msgh.get("b_val");
        String c_val = (String) msgh.get("c_val");
        out.println("<p>");
        out.println("a_val: <b>" + a_val + "</b><br />");
        out.println("b_val: <b>" + b_val + "</b><br />");
        out.println("c_val: <b>" + c_val + "</b><br />");
        if (c_val != null && c_val.length() > 0)
        {
            out.println("<br /><b style=\"color: #00aa00\">Successfully retrieved the \"c_val\" message!</b>");
        }
        else
        {
            out.println("<br /><b style=\"color: #aa0000\">No \"c_val\" message was found! Has it been sent yet?</b>");
        }
        out.println("</p>");

        out.println("<h4>Advanced Configuration of Mappings</h4>");
        out.println("<p>If you like, you can change the message 'mapping' in Edit mode"
                + " so that the \"<code>c_val</code>\" message is read in from a different message box.</i>");
    }

    protected void doEdit(RenderRequest request, RenderResponse response) throws PortletException, IOException
    {
        // Prepare the Edit Mappings form, which allows users to change the
        // names of the message boxes
        String id = this.getInstanceID(request);
        String msgSessionId = MessageHelper.getSessionID(request);
        MessageHelper.loadPrefs(request, id, msgSessionId);
        MessageUtils.prepareMappingForm(request, id, msgSessionId);
        response.setContentType("text/html");
        getPortletContext().getRequestDispatcher("/WEB-INF/jsp/edit_mappings.jsp").include(request, response);
    }

    public void processAction(ActionRequest request, ActionResponse response) throws PortletException, IOException
    {
        if (request.getPortletMode().equals(PortletMode.EDIT))
        {
            // Process the Edit Mappings form
            String id = this.getInstanceID(request);
            String msgSessionId = MessageHelper.getSessionID(request);
            MessageHelper.loadPrefs(request, id, msgSessionId);
            MessageUtils.processMappingForm(request, response, id, msgSessionId);
        }
    }

    public String getInstanceID(PortletRequest request)
    {
        // To make it easier to identify messages when using the debug
        // MessageReaderPortlet
        return "Portlet2" + MessageHelper.getPortletID(request);
    }

}
