/*
 * Copyright 2005-2006 Michelle Osmond Licensed under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package message.retriever;

import javax.portlet.PortletRequest;

import message.SessionIDRetriever;

/**
 * Implementation allowing access to the user's cross-context session id from a
 * cookie ("cookie_msg_session_id").
 * 
 * @author Michelle Osmond
 * @version 1.1
 */
public class CookieSessionIDRetriever implements SessionIDRetriever
{

    public String getSessionID(PortletRequest request)
    {
        String cookieName = "cookie_msg_session_id";
        String sessionID = null;
        String cookie = request.getProperty("cookie");

        if (cookie.indexOf(cookieName) >= 0)
        {
            int startValue = cookieName.length() + 1 + cookie.indexOf(cookieName);
            int endValue = cookie.length();
            if (cookie.indexOf(";", startValue) > 0)
            {
                endValue = cookie.indexOf(";", startValue);
            }
            sessionID = cookie.substring(startValue, endValue);
        }

        return sessionID;
    }
}
